@@ -1,7 +1,7 @@
 package App::CreateSparseFile;
 
 our $DATE = '2014-12-11'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -99,7 +99,7 @@ sub create_sparse_file {
     if (file_exists $fname) {
         if ($interactive) {
             return [200, "Cancelled"]
-                unless confirm "Confirm override existing file";
+                unless confirm "Confirm override existing file", {default=>0};
         } else {
             return [409, "File already exists"] unless $args{override};
         }
@@ -135,7 +135,7 @@ App::CreateSparseFile - Create sparse file
 
 =head1 VERSION
 
-This document describes version 0.03 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2014-12-11.
+This document describes version 0.04 of App::CreateSparseFile (from Perl distribution App-CreateSparseFile), released on 2014-12-11.
 
 =head1 SYNOPSIS
 
